==> weka-dev-3.7.7-test-sources.jar: weka/classifiers/pmml/consumer/RegressionTest.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Copyright 2008 University of Waikato, Hamilton, New Zealand
 */

package weka.classifiers.pmml.consumer;

import weka.core.FastVector;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * Tests the pmml Regression classifier.
 *
 * @author Mark Hall (mhall{[at]}pentaho{[dot]}com)
 * @version $Revision 1.0 $
 */
public class RegressionTest extends AbstractPMMLClassifierTest {

  public RegressionTest(String name) {
    super(name);
  }

  protected void setUp() throws Exception {
    m_modelNames = new FastVector();
    m_dataSetNames = new FastVector();
    m_modelNames.addElement("linear_regression_model.xml");
    m_modelNames.addElement("ELNINO_REGRESSION_SIMPLE.xml");
    m_dataSetNames.addElement("Elnino_small.arff");
    m_dataSetNames.addElement("Elnino_small.arff");
  }

  public static Test suite() {
    return new TestSuite(weka.classifiers.pmml.consumer.RegressionTest.class);
  }

  public static void main(String[] args) {
    junit.textui.TestRunner.run(suite());
  }
}

==> weka-dev-3.9.0-test-sources.jar: weka/classifiers/pmml/consumer/RegressionTest.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Copyright 2008 University of Waikato, Hamilton, New Zealand
 */

package weka.classifiers.pmml.consumer;

import java.util.ArrayList;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * Tests the pmml Regression classifier.
 * 
 * @author Mark Hall (mhall{[at]}pentaho{[dot]}com)
 * @version $Revision 1.0 $
 */
public class RegressionTest extends AbstractPMMLClassifierTest {

  public RegressionTest(String name) {
    super(name);
  }

  @Override
  protected void setUp() throws Exception {
    m_modelNames = new ArrayList<String>();
    m_dataSetNames = new ArrayList<String>();
    m_modelNames.add("linear_regression_model.xml");
    m_modelNames.add("ELNINO_REGRESSION_SIMPLE.xml");
    m_dataSetNames.add("Elnino_small.arff");
    m_dataSetNames.add("Elnino_small.arff");
  }

  public static Test suite() {
    return new TestSuite(weka.classifiers.pmml.consumer.RegressionTest.class);
  }

  public static void main(String[] args) {
    junit.textui.TestRunner.run(suite());
  }
}
